@@ -546,14 +546,14 @@ def mass_estimated_from_radius_assuming_rockyish(self, distribution=False, **kw)
         If True, return an astropy.uncertainty.Distribution,
         which can be used for error propagation.
     """
-    mu = np.array([3.377, 0.053, -0.172, -1.018])
+    mu = np.array([3.395e00, -1.000e-03, -2.630e-01, -1.345e00])
     m, b, m_sigma, b_sigma = mu
     covariance_matrix = np.array(
         [
-            [8.11697658e-04, 7.94668946e-05, -2.85573628e-04, -5.03067330e-04],
-            [7.94668946e-05, 1.16297907e-03, 1.05364126e-04, 5.94249835e-04],
-            [-2.85573628e-04, 1.05364126e-04, 1.24167859e-03, 2.33621940e-03],
-            [-5.03067330e-04, 5.94249835e-04, 2.33621940e-03, 1.04721141e-02],
+            [9.92306400e-04, 3.08188824e-05, -5.21201960e-04, -9.20479438e-04],
+            [3.08188824e-05, 8.54410574e-04, 7.64582766e-06, 7.91519234e-05],
+            [-5.21201960e-04, 7.64582766e-06, 1.62727147e-03, 2.80883165e-03],
+            [-9.20479438e-04, 7.91519234e-05, 2.80883165e-03, 1.08430253e-02],
         ]
     )
     rocky_radius_cutoff = 1.8 * u.Rearth
